==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn.md <==
# AwsIdentityAccessManagementAddOn


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn')
```



| Illustration | AwsIdentityAccessManagementAddOn | AwsIdentityAccessManagementAddOnCard | AwsIdentityAccessManagementAddOnGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn.png) | ![illustration for AwsIdentityAccessManagementAddOn](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn.Local.png) | ![illustration for AwsIdentityAccessManagementAddOnCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOnCard.Local.png) | ![illustration for AwsIdentityAccessManagementAddOnGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOnGroup.Local.png) |




## AwsIdentityAccessManagementAddOn

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAddOn
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn')

' renders the element
AwsIdentityAccessManagementAddOn('AwsIdentityAccessManagementAddOn', 'Aws Identity Access Management Add On', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAddOn
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn')

' renders the element
AwsIdentityAccessManagementAddOn('AwsIdentityAccessManagementAddOn', 'Aws Identity Access Management Add On', 'an optional tech label')
@enduml
```

## AwsIdentityAccessManagementAddOnCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAddOnCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn')

' renders the element
AwsIdentityAccessManagementAddOnCard('AwsIdentityAccessManagementAddOnCard', 'Aws Identity Access Management Add On Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAddOnCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn')

' renders the element
AwsIdentityAccessManagementAddOnCard('AwsIdentityAccessManagementAddOnCard', 'Aws Identity Access Management Add On Card', 'an optional description')
@enduml
```

## AwsIdentityAccessManagementAddOnGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAddOnGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn')

' renders the element
AwsIdentityAccessManagementAddOnGroup('AwsIdentityAccessManagementAddOnGroup', 'Aws Identity Access Management Add On Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAddOnGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn')

' renders the element
AwsIdentityAccessManagementAddOnGroup('AwsIdentityAccessManagementAddOnGroup', 'Aws Identity Access Management Add On Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn.md <==
# AwsIdentityAccessManagementAddOn


```text
aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn
```

```text
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn')
```



| Illustration | AwsIdentityAccessManagementAddOn | AwsIdentityAccessManagementAddOnCard | AwsIdentityAccessManagementAddOnGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn.png) | ![illustration for AwsIdentityAccessManagementAddOn](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn.Local.png) | ![illustration for AwsIdentityAccessManagementAddOnCard](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOnCard.Local.png) | ![illustration for AwsIdentityAccessManagementAddOnGroup](../../../aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOnGroup.Local.png) |




## AwsIdentityAccessManagementAddOn

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAddOn
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn')

' renders the element
AwsIdentityAccessManagementAddOn('AwsIdentityAccessManagementAddOn', 'Aws Identity Access Management Add On', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAddOn
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn')

' renders the element
AwsIdentityAccessManagementAddOn('AwsIdentityAccessManagementAddOn', 'Aws Identity Access Management Add On', 'an optional tech label')
@enduml
```

## AwsIdentityAccessManagementAddOnCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAddOnCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn')

' renders the element
AwsIdentityAccessManagementAddOnCard('AwsIdentityAccessManagementAddOnCard', 'Aws Identity Access Management Add On Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAddOnCard
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn')

' renders the element
AwsIdentityAccessManagementAddOnCard('AwsIdentityAccessManagementAddOnCard', 'Aws Identity Access Management Add On Card', 'an optional description')
@enduml
```

## AwsIdentityAccessManagementAddOnGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAddOnGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn')

' renders the element
AwsIdentityAccessManagementAddOnGroup('AwsIdentityAccessManagementAddOnGroup', 'Aws Identity Access Management Add On Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsIdentityAccessManagementAddOnGroup
include('aws-20210730/Resource/SecurityIdentityAndCompliance/AwsIdentityAccessManagementAddOn')

' renders the element
AwsIdentityAccessManagementAddOnGroup('AwsIdentityAccessManagementAddOnGroup', 'Aws Identity Access Management Add On Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
